(function (global, factory) {
    if (typeof define === "function" && define.amd) {
        define(['module', 'exports'], factory);
    } else if (typeof exports !== "undefined") {
        factory(module, exports);
    } else {
        var mod = {
            exports: {}
        };
        factory(mod, mod.exports);
        global.sync = mod.exports;
    }
})(this, function (module, exports) {
    'use strict';

    Object.defineProperty(exports, "__esModule", {
        value: true
    });
    exports.default = sync;
    function sync(animationName) {
        var elements = new Set();
        var eventTime = void 0;

        function animationStart(event) {
            if (event.animationName === animationName) {
                elements.add(event.target);
            }
        }

        function animationIteration(event) {
            if (event.animationName === animationName) {
                elements.add(event.target);

                requestAnimationFrame(function (frameTime) {
                    if (frameTime !== eventTime) {
                        restart(elements);
                    }

                    eventTime = frameTime;
                });
            }
        }

        window.addEventListener('animationstart', animationStart, true);
        window.addEventListener('animationiteration', animationIteration, true);

        return {
            free: function free() {
                window.removeEventListener('animationstart', animationStart);
                window.removeEventListener('animationiteration', animationIteration);

                this.start();
                elements.clear();
            },
            start: function start() {
                elements.forEach(function (el) {
                    el.style.removeProperty('animation');
                });
            },
            stop: function stop() {
                elements.forEach(function (el) {
                    el.style.setProperty('animation', 'none');
                });
            },
            pause: function pause() {
                elements.forEach(function (el) {
                    el.style.setProperty('animation-play-state', 'paused');
                });
            }
        };
    }

    function restart(elements) {
        elements.forEach(function (el) {
            if (window.getComputedStyle(el).animationPlayState !== 'paused') {
                el.style.setProperty('animation', 'none');
            }
        });

        requestAnimationFrame(function () {
            elements.forEach(function (el) {
                if (window.getComputedStyle(el).animationPlayState !== 'paused') {
                    el.style.removeProperty('animation');
                }
            });
        });
    }
    module.exports = exports['default'];
});